API Reference
=============

.. currentmodule:: pyaragorn

This section contains a complete reference of the ``pyaragorn`` module API.


Module
------

.. automodule:: pyaragorn


RNA Finder
----------

.. autosummary::
   :nosignatures:

   RNAFinder

.. toctree::
    :maxdepth: 1
    :hidden:

    rna_finder


Genes
-----

.. autosummary::
   :nosignatures:

   Gene
   TRNAGene
   TMRNAGene

.. toctree::
    :maxdepth: 1
    :hidden:

    gene
    trna_gene
    tmrna_gene
